database

package
v0.0.0-...-b140ed9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConnectPgx

func ConnectPgx(host string, port int, user, password, dbname, sslmode string) (*pgxpool.Pool, error)

ConnectPgx creates a pgx connection pool from individual config values.

Types

This section is empty.

Jump to